import type { WorkbenchConfig } from '@agentuity/core/workbench';
import type { WorkbenchInstance } from './types';
export declare function createWorkbench(config?: WorkbenchConfig): WorkbenchInstance;
//# sourceMappingURL=workbench.d.ts.map