export interface AppProps {
    configBase64: string;
}
export declare function App({ configBase64 }: AppProps): import("react/jsx-runtime").JSX.Element;
export default App;
//# sourceMappingURL=App.d.ts.map