declare const Logo: import("react").ForwardRefExoticComponent<{
    className?: string;
    alt?: string;
} & import("react").RefAttributes<SVGSVGElement>>;
export default Logo;
//# sourceMappingURL=logo.d.ts.map